import React from 'react';
import { IOptionProps, OptionLabelKey } from '../../../@types';
import { ILabelProps } from '../../elements/label/Label';
import { IAddAreaProps, AutocompleteList } from './AutocompleteList';
import { AutocompleteGroupList } from './AutocompleteGroupList';
import { AutocompleteNoItem } from './AutocompleteNoItem';
export interface IAutocompleteProps<T> {
    /**
     * Defines class property
     */
    className?: string;
    /**
     * Defines the appearance or layout of container around Autocomplete & Label
     */
    containerClass?: string;
    /**
     * Defines the auto complete search input disabled
     */
    disabled?: boolean;
    /**
     * Hide clear icon
     */
    hideClear?: boolean;
    /**
     * Defines key for Option for label
     */
    labelKey?: OptionLabelKey;
    /**
     * Defines the appearance or layout of the Label component
     */
    labelProps?: ILabelProps;
    /**
     * Defines the labelText for form label
     */
    labelText?: string;
    /**
     * Defines the callback hander when option selected
     */
    onChange?: (props: any) => void;
    /**
     * Defines the callback for search input text
     */
    onInputValueChange?: (searchText?: string) => void;
    /**
     * Defines the callback for internal state changes
     */
    onStateChange?: (changes: any) => void;
    /**
     * Defines the list items details in Autocomplete
     */
    options: T[];
    /**
     * Defines the options contianer class to define
     * the layout
     */
    optionsContainerClass?: string;
    /**
     * Defines the options container stack order
     */
    optionsZIndex?: string;
    /**
     * Defines the text for no option list item
     */
    noOptionText?: string;
    /**
     * Defines the input placeholder
     */
    placeholder?: string;
    /**
     * Defines the add area when auto complete item not found
     */
    renderAddArea?: (props: IAddAreaProps<IOptionProps>) => React.ReactNode;
    /**
     * Defiens the list items rendering whether normal or grouped list
     */
    renderList?: (props: any) => React.ReactNode;
    /**
     * Defines the list option component
     */
    renderOptionLabel?: (props: any) => React.ReactNode;
    /**
     * Enable set previously selected item on blur
     */
    resetOnBlur?: boolean;
    /**
     * Defines the default selected option from the list
     */
    defaultSelected?: T;
    /**
     * Defines the current selected option from the list
     */
    selected?: T;
    /**
     * Show red border on the control when invalid
     */
    invalid?: boolean;
    /**
     * Defines the loader for the control, pass it null when there is no loading is completed.
     */
    loader?: React.ReactNode;
    /**
     * Defines if the records loading. Used for server-side search.
     */
    loading?: boolean;
    /**
     * Defines loading text
     */
    loadingLabel?: string;
    /**
     * Defines avatar visibility in each option
     */
    showAvatar?: boolean;
    /**
    /**
     * Defines the icon for toggle button on the rightside
     */
    toggleIconType?: string;
}
declare const Autocomplete: {
    <T extends IOptionProps>({ labelKey, onChange, onInputValueChange, onStateChange, options, resetOnBlur, defaultSelected, selected, loader, ...other }: IAutocompleteProps<T>): JSX.Element;
    List: typeof AutocompleteList;
    GroupList: typeof AutocompleteGroupList;
    ListContainer: React.ForwardRefExoticComponent<import("./AutocompleteListContianer").IOptionsContainerProps & React.RefAttributes<unknown>>;
    Item: React.ForwardRefExoticComponent<import("./AutocompleteItem").IOptionItemProps<IOptionProps> & React.RefAttributes<unknown>>;
    NoItem: typeof AutocompleteNoItem;
};
export default Autocomplete;
//# sourceMappingURL=Autocomplete.d.ts.map