import React from 'react';
import { Placement } from '@floating-ui/react';
import { Delay } from '../../types';
export interface ITooltipOptions {
    /**
     * Waits for the specified time when the event listener runs before changing the open state
     */
    delay?: number | Delay;
    /**
     * Defines initial open state
     */
    initialOpen?: boolean;
    /**
     * Defines tooltip is interactive
     */
    interactive?: boolean;
    /**
     * Whether the logic only runs for mouse input, ignoring both touch and pen pointer inputs.
     */
    mouseOnly?: boolean;
    /**
     * Defines tooltip placement
     */
    placement?: Placement;
    /**
     * Defines offset number between trigger and content box
     */
    offset?: number;
    /**
     * Open state is controlled tooltip
     */
    open?: boolean;
    /**
     * setOpen function for controlled tooltip
     */
    onOpenChange?: (open: boolean) => void;
    /**
     * Waits until the user’s cursor is at “rest” over the reference element before changing the open state
     */
    restMs?: number;
    /**
     * Defines trigger on click else hover
     */
    triggerOnClick?: boolean;
}
export declare function useTooltip({ delay, initialOpen, interactive, mouseOnly, placement, offset: offsetValue, open: controlledOpen, onOpenChange: setControlledOpen, restMs, triggerOnClick, }?: ITooltipOptions): {
    placement: Placement;
    strategy: import("@floating-ui/react").Strategy;
    middlewareData: import("@floating-ui/react").MiddlewareData;
    x: number | null;
    y: number | null;
    update: () => void;
    reference: (node: import("@floating-ui/react").ReferenceType | null) => void;
    floating: (node: HTMLElement | null) => void;
    positionReference: (node: import("@floating-ui/react").ReferenceType | null) => void;
    context: {
        x: number | null;
        y: number | null;
        placement: Placement;
        strategy: import("@floating-ui/react").Strategy;
        middlewareData: import("@floating-ui/react").MiddlewareData;
        update: () => void;
        reference: (node: import("@floating-ui/react").ReferenceType | null) => void;
        floating: (node: HTMLElement | null) => void;
        isPositioned: boolean;
        open: boolean;
        onOpenChange: (open: boolean) => void;
        events: import("@floating-ui/react").FloatingEvents;
        dataRef: React.MutableRefObject<import("@floating-ui/react").ContextData>;
        nodeId: string | undefined;
        floatingId: string;
        refs: import("@floating-ui/react").ExtendedRefs<import("@floating-ui/react").ReferenceType>;
        elements: import("@floating-ui/react").ExtendedElements<import("@floating-ui/react").ReferenceType>;
    };
    refs: import("@floating-ui/react").ExtendedRefs<import("@floating-ui/react").ReferenceType>;
    elements: import("@floating-ui/react").ExtendedElements<import("@floating-ui/react").ReferenceType>;
    isPositioned: boolean;
    getReferenceProps: (userProps?: React.HTMLProps<Element> | undefined) => Record<string, unknown>;
    getFloatingProps: (userProps?: React.HTMLProps<HTMLElement> | undefined) => Record<string, unknown>;
    getItemProps: (userProps?: React.HTMLProps<HTMLElement> | undefined) => Record<string, unknown>;
    arrowRef: React.MutableRefObject<null>;
    open: boolean;
    setOpen: (open: boolean) => void;
};
//# sourceMappingURL=useTooltip.d.ts.map