import { SLIUnitEnum, VolumeUnitEnum, WeightUnitEnum } from '../constants/impactConstants';
export declare type UnitToType = SLIUnitEnum | VolumeUnitEnum | WeightUnitEnum;
interface IautoScaleUnitValueProps {
    /**
     * Defines the unit of each impact based on weight, volume or sli type.
     * Based on this unit, autoScale value will be displaye corresponding possible units
     */
    unit: string;
    /**
     * Defines the unit of each impact based on which fixed scale up or down of value will be done
     */
    unitTo?: UnitToType;
    /**
     * Defines the impact value, which will be formatted based on options
     */
    value: number;
}
export declare function autoScaleWeightValue(value: number): {
    unit: string;
    unitDescription: string;
    unitTo: WeightUnitEnum;
    value: number;
};
export declare function autoScaleVolumeValue(value: number): {
    unit: string;
    unitDescription: string;
    unitTo: VolumeUnitEnum;
    value: number;
};
export declare function autoScaleSLIValue(value: number): {
    unit: string;
    unitDescription: string;
    unitTo: SLIUnitEnum;
    value: number;
};
export declare function autoScaleToSLI({ value, unitTo }: {
    value: number;
    unitTo: SLIUnitEnum;
}): {
    unit: string;
    unitDescription: string;
    unitTo: SLIUnitEnum;
    value: number;
};
export declare function autoScaleToWeight({ value, unitTo }: {
    value: number;
    unitTo: WeightUnitEnum;
}): {
    unit: string;
    unitDescription: string;
    unitTo: WeightUnitEnum;
    value: number;
};
export declare function autoScaleToVolume({ value, unitTo }: {
    value: number;
    unitTo: VolumeUnitEnum;
}): {
    unit: string;
    unitDescription: string;
    unitTo: VolumeUnitEnum;
    value: number;
};
export declare function autoScaleUnitValue({ unit, unitTo, value }: IautoScaleUnitValueProps): {
    unit: string;
    unitDescription: string;
    unitTo: string;
    value: number;
};
export {};
//# sourceMappingURL=autoScaleUnitValue.d.ts.map